@@ -10,7 +10,9 @@ from dateutil.parser import parse
 
 from .common import IconFactory
 
-__all__ = ['Date', 'CellRendererDate', 'Time', 'CellRendererTime', 'DateTime']
+__all__ = [
+    'Date', 'CellRendererDate', 'Time', 'CellRendererTime', 'DateTime',
+    'date_parse']
 
 _ = gettext.gettext
 
