@@ -1,5 +1,5 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from window import *
-from email import *
-from limit import *
+from .window import Window
+
+__all__ = [Window]
